@@ -1,10 +1,11 @@
 ### Skip all the CI's and CRAN if there is no internet or a gov shutdown
 
 skip_if_no_internet <- function(){
-  curl::has_internet()
-  skip_on_appveyor()
-  skip_on_cran()
-  skip_on_travis()
+  if (!curl::has_internet()) {
+    skip_on_appveyor()
+    skip_on_cran()
+    skip_on_travis()  
+  }
 }
 
 skip_if_shutdown <- function(){
